pub struct UnigraphError {
pub display: String,
pub debug: Option<String>,
}Expand description
This is a centralized Error struct for unigraph code that can be used cross-platform. It can be serialized to and from JSON and passed cross php or javascript boundary.
Error (or this crate) also provides a set of formatters that can format it with CLI colors or without, or serialize it to JSON for passing up the stack (e.g. PHP caller)
Fields
display: Stringdebug: Option<String>Implementations
Sourceimpl UnigraphError
impl UnigraphError